@@ -6,9 +6,10 @@ import (
 
 var issueCmd = &cobra.Command{
 	Use:              "issue",
+	Aliases:          []string{"i"},
 	Short:            `Describe, list, and create issues`,
 	Long:             ``,
-	PersistentPreRun: LabPersistentPreRun,
+	PersistentPreRun: labPersistentPreRun,
 	Run: func(cmd *cobra.Command, args []string) {
 		if list, _ := cmd.Flags().GetBool("list"); list {
 			issueListCmd.Run(cmd, args)
