@@ -4,6 +4,7 @@ import (
 	"fmt"
 	"strings"
 
+	"github.com/MakeNowJust/heredoc/v2"
 	"github.com/rsteube/carapace"
 	"github.com/spf13/cobra"
 	"github.com/zaquestion/lab/internal/action"
@@ -13,36 +14,31 @@ import (
 var issueCloseCmd = &cobra.Command{
 	Use:              "close [remote] <id>",
 	Aliases:          []string{"delete"},
-	Short:            "Close issue by id",
-	Long:             ``,
+	Short:            "Close issue by ID",
 	Args:             cobra.MinimumNArgs(1),
-	PersistentPreRun: LabPersistentPreRun,
-	Example: `lab issue close 1234
-lab issue close --duplicate 123 1234
-lab issue close --duplicate other-project#123 1234`,
+	PersistentPreRun: labPersistentPreRun,
+	Example: heredoc.Doc(`
+		lab issue close 1234
+		lab issue close origin --duplicate 123 1234
+		lab issue close --duplicate other-project#123 1234`),
 	Run: func(cmd *cobra.Command, args []string) {
 		rn, id, err := parseArgsRemoteAndID(args)
 		if err != nil {
 			log.Fatal(err)
 		}
 
-		p, err := lab.FindProject(rn)
-		if err != nil {
-			log.Fatal(err)
-		}
-
-		dupId, _ := cmd.Flags().GetString("duplicate")
-		if dupId != "" {
-			if !strings.Contains(dupId, "#") {
-				dupId = "#" + dupId
+		dupID, _ := cmd.Flags().GetString("duplicate")
+		if dupID != "" {
+			if !strings.Contains(dupID, "#") {
+				dupID = "#" + dupID
 			}
-			err = lab.IssueDuplicate(p.ID, int(id), dupId)
+			err = lab.IssueDuplicate(rn, int(id), dupID)
 			if err != nil {
 				log.Fatal(err)
 			}
-			fmt.Printf("Issue #%d closed as duplicate of %s\n", id, dupId)
+			fmt.Printf("Issue #%d closed as duplicate of %s\n", id, dupID)
 		} else {
-			err = lab.IssueClose(p.ID, int(id))
+			err = lab.IssueClose(rn, int(id))
 			if err != nil {
 				log.Fatal(err)
 			}
