@@ -2,6 +2,7 @@ package cmd
 
 import (
 	"fmt"
+	"github.com/MakeNowJust/heredoc/v2"
 
 	"github.com/rsteube/carapace"
 	"github.com/spf13/cobra"
@@ -10,22 +11,19 @@ import (
 )
 
 var issueReopenCmd = &cobra.Command{
-	Use:              "reopen [remote] <id>",
-	Short:            "Reopen a closed issue",
-	Long:             ``,
-	PersistentPreRun: LabPersistentPreRun,
+	Use:   "reopen [remote] <id>",
+	Short: "Reopen a closed issue",
+	Example: heredoc.Doc(`
+		lab issue reopen 1
+		lab issue reopen upstream 2`),
+	PersistentPreRun: labPersistentPreRun,
 	Run: func(cmd *cobra.Command, args []string) {
 		rn, id, err := parseArgsRemoteAndID(args)
 		if err != nil {
 			log.Fatal(err)
 		}
 
-		p, err := lab.FindProject(rn)
-		if err != nil {
-			log.Fatal(err)
-		}
-
-		err = lab.IssueReopen(p.ID, int(id))
+		err = lab.IssueReopen(rn, int(id))
 		if err != nil {
 			log.Fatal(err)
 		}
