@@ -12,21 +12,16 @@ import (
 var issueSubscribeCmd = &cobra.Command{
 	Use:              "subscribe [remote] <id>",
 	Aliases:          []string{},
-	Short:            "Subscribe to issue",
-	Long:             ``,
-	PersistentPreRun: LabPersistentPreRun,
+	Short:            "Subscribe to an issue",
+	Example:          "lab issue subscribe origin 10",
+	PersistentPreRun: labPersistentPreRun,
 	Run: func(cmd *cobra.Command, args []string) {
 		rn, id, err := parseArgsRemoteAndID(args)
 		if err != nil {
 			log.Fatal(err)
 		}
 
-		p, err := lab.FindProject(rn)
-		if err != nil {
-			log.Fatal(err)
-		}
-
-		err = lab.IssueSubscribe(p.ID, int(id))
+		err = lab.IssueSubscribe(rn, int(id))
 		if err != nil {
 			log.Fatal(err)
 		}
