@@ -12,21 +12,17 @@ import (
 var issueUnsubscribeCmd = &cobra.Command{
 	Use:              "unsubscribe [remote] <id>",
 	Aliases:          []string{},
-	Short:            "Unubscribe from issue",
+	Short:            "Unubscribe from an issue",
 	Long:             ``,
-	PersistentPreRun: LabPersistentPreRun,
+	Example:          "lab issue unsubscribe origin 10",
+	PersistentPreRun: labPersistentPreRun,
 	Run: func(cmd *cobra.Command, args []string) {
 		rn, id, err := parseArgsRemoteAndID(args)
 		if err != nil {
 			log.Fatal(err)
 		}
 
-		p, err := lab.FindProject(rn)
-		if err != nil {
-			log.Fatal(err)
-		}
-
-		err = lab.IssueUnsubscribe(p.ID, int(id))
+		err = lab.IssueUnsubscribe(rn, int(id))
 		if err != nil {
 			log.Fatal(err)
 		}
