@@ -1,6 +1,7 @@
 package cmd
 
 import (
+	"github.com/MakeNowJust/heredoc/v2"
 	"github.com/rsteube/carapace"
 	"github.com/spf13/cobra"
 	"github.com/zaquestion/lab/internal/action"
@@ -8,11 +9,13 @@ import (
 )
 
 var labelDeleteCmd = &cobra.Command{
-	Use:              "delete [remote] <name>",
-	Aliases:          []string{"remove"},
-	Short:            "Deletes an existing label",
-	Long:             ``,
-	PersistentPreRun: LabPersistentPreRun,
+	Use:     "delete [remote] <name>",
+	Aliases: []string{"remove"},
+	Short:   "Deletes an existing label",
+	Example: heredoc.Doc(`
+		lab label delete my-label
+		lab label delete origin my-label`),
+	PersistentPreRun: labPersistentPreRun,
 	Args:             cobra.MinimumNArgs(1),
 	Run: func(cmd *cobra.Command, args []string) {
 		rn, name, err := parseArgsRemoteAndProject(args)
@@ -20,7 +23,7 @@ var labelDeleteCmd = &cobra.Command{
 			log.Fatal(err)
 		}
 
-		labels, err := MapLabels(rn, []string{name})
+		labels, err := mapLabels(rn, []string{name})
 		if err != nil {
 			log.Fatal(err)
 		}
