@@ -6,12 +6,10 @@ import (
 
 var milestoneCmd = &cobra.Command{
 	Use:              "milestone",
-	Short:            `List and search milestones`,
-	Long:             ``,
-	PersistentPreRun: LabPersistentPreRun,
+	Short:            "List and search milestones",
+	PersistentPreRun: labPersistentPreRun,
 	Run: func(cmd *cobra.Command, args []string) {
 		cmd.Help()
-		return
 	},
 }
 
