@@ -1,6 +1,7 @@
 package cmd
 
 import (
+	"github.com/MakeNowJust/heredoc/v2"
 	"github.com/rsteube/carapace"
 	"github.com/spf13/cobra"
 	gitlab "github.com/xanzy/go-gitlab"
@@ -9,12 +10,13 @@ import (
 )
 
 var milestoneCreateCmd = &cobra.Command{
-	Use:              "create [remote] <name>",
-	Aliases:          []string{"add"},
-	Short:            "Create a new milestone",
-	Long:             ``,
-	Example:          "lab milestone create my-milestone",
-	PersistentPreRun: LabPersistentPreRun,
+	Use:     "create [remote] <name>",
+	Aliases: []string{"add"},
+	Short:   "Create a new milestone",
+	Example: heredoc.Doc(`
+		lab milestone create my-milestone
+		lab milestone create upstream 'my title' --description 'Some Description'`),
+	PersistentPreRun: labPersistentPreRun,
 	Args:             cobra.MinimumNArgs(1),
 	Run: func(cmd *cobra.Command, args []string) {
 		rn, title, err := parseArgsRemoteAndProject(args)
@@ -44,11 +46,11 @@ func init() {
 	carapace.Gen(milestoneCreateCmd).PositionalCompletion(
 		action.Remotes(),
 		carapace.ActionCallback(func(c carapace.Context) carapace.Action {
-			if project, _, err := parseArgsRemoteAndProject(c.Args); err != nil {
+			project, _, err := parseArgsRemoteAndProject(c.Args)
+			if err != nil {
 				return carapace.ActionMessage(err.Error())
-			} else {
-				return action.Milestones(project, action.MilestoneOpts{Active: true})
 			}
+			return action.Milestones(project, action.MilestoneOpts{Active: true})
 		}),
 	)
 }
