@@ -9,7 +9,7 @@ var mrCmd = &cobra.Command{
 	Use:              "mr",
 	Short:            `Describe, list, and create merge requests`,
 	Long:             ``,
-	PersistentPreRun: LabPersistentPreRun,
+	PersistentPreRun: labPersistentPreRun,
 	Run: func(cmd *cobra.Command, args []string) {
 		if list, _ := cmd.Flags().GetBool("list"); list {
 			listCmd.Run(cmd, args)
