@@ -12,11 +12,11 @@ import (
 )
 
 var mrBrowseCmd = &cobra.Command{
-	Use:              "browse [remote] <id>",
+	Use:              "browse [remote] [<MR id or branch>]",
 	Aliases:          []string{"b"},
 	Short:            "View merge request in a browser",
-	Long:             ``,
-	PersistentPreRun: LabPersistentPreRun,
+	Example:          "lab mr browse origin",
+	PersistentPreRun: labPersistentPreRun,
 	Run: func(cmd *cobra.Command, args []string) {
 		rn, num, err := parseArgsWithGitBranchMR(args)
 		if err != nil {
