@@ -10,22 +10,17 @@ import (
 )
 
 var mrCloseCmd = &cobra.Command{
-	Use:              "close [remote] <id>",
+	Use:              "close [remote] [<MR id or branch>]",
 	Short:            "Close merge request",
-	Long:             ``,
-	PersistentPreRun: LabPersistentPreRun,
+	Example:          "lab mr close origin 10",
+	PersistentPreRun: labPersistentPreRun,
 	Run: func(cmd *cobra.Command, args []string) {
 		rn, id, err := parseArgsWithGitBranchMR(args)
 		if err != nil {
 			log.Fatal(err)
 		}
 
-		p, err := lab.FindProject(rn)
-		if err != nil {
-			log.Fatal(err)
-		}
-
-		err = lab.MRClose(p.ID, int(id))
+		err = lab.MRClose(rn, int(id))
 		if err != nil {
 			log.Fatal(err)
 		}
