@@ -3,6 +3,7 @@ package cmd
 import (
 	"fmt"
 
+	"github.com/MakeNowJust/heredoc/v2"
 	"github.com/rsteube/carapace"
 	"github.com/spf13/cobra"
 	gitlab "github.com/xanzy/go-gitlab"
@@ -13,29 +14,28 @@ import (
 var mergeImmediate bool
 
 var mrMergeCmd = &cobra.Command{
-	Use:   "merge [remote] <id>",
+	Use:   "merge [remote] [<MR id or branch>]",
 	Short: "Merge an open merge request",
-	Long: `Merges an open merge request. If the pipeline in the project is
-enabled and is still running for that specific MR, by default,
-this command will sets the merge to only happen when the pipeline
-succeeds`,
-	PersistentPreRun: LabPersistentPreRun,
+	Long: heredoc.Doc(`
+		Merges an open merge request. If the pipeline in the project is
+		enabled and is still running for that specific MR, by default,
+		this command will sets the merge to only happen when the pipeline
+		succeeds.`),
+	Example: heredoc.Doc(`
+		lab mr merge origin 10
+		lab mr merge upstream 11 -i`),
+	PersistentPreRun: labPersistentPreRun,
 	Run: func(cmd *cobra.Command, args []string) {
 		rn, id, err := parseArgsWithGitBranchMR(args)
 		if err != nil {
 			log.Fatal(err)
 		}
 
-		p, err := lab.FindProject(rn)
-		if err != nil {
-			log.Fatal(err)
-		}
-
 		opts := gitlab.AcceptMergeRequestOptions{
 			MergeWhenPipelineSucceeds: gitlab.Bool(!mergeImmediate),
 		}
 
-		err = lab.MRMerge(p.ID, int(id), &opts)
+		err = lab.MRMerge(rn, int(id), &opts)
 		if err != nil {
 			log.Fatal(err)
 		}
