@@ -8,21 +8,17 @@ import (
 )
 
 var mrRebaseCmd = &cobra.Command{
-	Use:              "rebase [remote] <id>",
+	Use:              "rebase [remote] [<MR id or branch>]",
 	Short:            "Rebase an open merge request",
-	PersistentPreRun: LabPersistentPreRun,
+	Example:          "lab mr rebase upstream 20",
+	PersistentPreRun: labPersistentPreRun,
 	Run: func(cmd *cobra.Command, args []string) {
 		rn, id, err := parseArgsWithGitBranchMR(args)
 		if err != nil {
 			log.Fatal(err)
 		}
 
-		p, err := lab.FindProject(rn)
-		if err != nil {
-			log.Fatal(err)
-		}
-
-		err = lab.MRRebase(p.ID, int(id))
+		err = lab.MRRebase(rn, int(id))
 		if err != nil {
 			log.Fatal(err)
 		}
