@@ -2,6 +2,7 @@ package cmd
 
 import (
 	"fmt"
+	"github.com/MakeNowJust/heredoc/v2"
 
 	"github.com/rsteube/carapace"
 	"github.com/spf13/cobra"
@@ -10,23 +11,20 @@ import (
 )
 
 var mrUnsubscribeCmd = &cobra.Command{
-	Use:              "unsubscribe [remote] <id>",
-	Aliases:          []string{},
-	Short:            "Unubscribe from merge request",
-	Long:             ``,
-	PersistentPreRun: LabPersistentPreRun,
+	Use:     "unsubscribe [remote] [<MR id or branch>]",
+	Aliases: []string{},
+	Short:   "Unubscribe from merge request",
+	Example: heredoc.Doc(`
+		lab mr unsubscribe 11
+		lab mr unsubscribe origin 12`),
+	PersistentPreRun: labPersistentPreRun,
 	Run: func(cmd *cobra.Command, args []string) {
 		rn, id, err := parseArgsWithGitBranchMR(args)
 		if err != nil {
 			log.Fatal(err)
 		}
 
-		p, err := lab.FindProject(rn)
-		if err != nil {
-			log.Fatal(err)
-		}
-
-		err = lab.MRUnsubscribe(p.ID, int(id))
+		err = lab.MRUnsubscribe(rn, int(id))
 		if err != nil {
 			log.Fatal(err)
 		}
