@@ -9,10 +9,13 @@ var projectBrowseCmd = &cobra.Command{
 	Use:              "browse [remote]",
 	Aliases:          []string{"b"},
 	Short:            "View project in a browser",
-	Long:             ``,
-	PersistentPreRun: LabPersistentPreRun,
+	Example:          "lab project browse origin",
+	PersistentPreRun: labPersistentPreRun,
 	Run: func(cmd *cobra.Command, args []string) {
 		rn, _, err := parseArgsRemoteAndID(args)
+		if err != nil {
+			log.Fatal(err)
+		}
 
 		p, err := lab.FindProject(rn)
 		if err != nil {
