@@ -1,39 +1,31 @@
 package cmd
 
 import (
+	"github.com/MakeNowJust/heredoc/v2"
+	lab "github.com/zaquestion/lab/internal/gitlab"
 	"net/url"
 	"path"
 	"strconv"
 
 	"github.com/rsteube/carapace"
 	"github.com/spf13/cobra"
-	"github.com/spf13/viper"
 	"github.com/zaquestion/lab/internal/action"
 )
 
 var snippetBrowseCmd = &cobra.Command{
-	Use:              "browse [remote] <id>",
-	Short:            "View personal or project snippet in a browser",
-	Long:             ``,
-	PersistentPreRun: LabPersistentPreRun,
+	Use:   "browse [remote] <id>",
+	Short: "View personal or project snippet in a browser",
+	Example: heredoc.Doc(`
+		lab snippet browse
+		lab snippet browse upstream`),
+	PersistentPreRun: labPersistentPreRun,
 	Run: func(cmd *cobra.Command, args []string) {
 		rn, id, err := parseArgsRemoteAndID(args)
 		if err != nil {
 			log.Fatal(err)
 		}
 
-		c := viper.AllSettings()["core"]
-		var cfg map[string]interface{}
-		switch v := c.(type) {
-		// Most run this is the type
-		case []map[string]interface{}:
-			cfg = v[0]
-		// On the first run when the cfg is created it comes in as this type
-		// for whatever reason
-		case map[string]interface{}:
-			cfg = v
-		}
-		host := cfg["host"].(string)
+		host := lab.Host()
 		hostURL, err := url.Parse(host)
 		if err != nil {
 			log.Fatal(err)
