@@ -2,6 +2,7 @@ package cmd
 
 import (
 	"fmt"
+	"github.com/MakeNowJust/heredoc/v2"
 
 	"github.com/rsteube/carapace"
 	"github.com/spf13/cobra"
@@ -13,8 +14,10 @@ import (
 var snippetDeleteCmd = &cobra.Command{
 	Use:   "delete [remote] <id>",
 	Short: "Delete a project or personal snippet",
-	Long:  ``,
-	Args:  cobra.MinimumNArgs(1),
+	Example: heredoc.Doc(`
+		lab snippet delete origin 2147103
+		lab snippet delete -g 2147104`),
+	Args: cobra.MinimumNArgs(1),
 	Run: func(cmd *cobra.Command, args []string) {
 		rn, id, err := parseArgsRemoteAndID(args)
 		if err != nil {
@@ -29,11 +32,7 @@ var snippetDeleteCmd = &cobra.Command{
 			return
 		}
 
-		project, err := lab.FindProject(rn)
-		if err != nil {
-			log.Fatal(err)
-		}
-		err = lab.ProjectSnippetDelete(project.ID, int(id))
+		err = lab.ProjectSnippetDelete(rn, int(id))
 		if err != nil {
 			log.Fatal(err)
 		}
