@@ -2,7 +2,6 @@ package cmd
 
 import (
 	"os/exec"
-	"strings"
 	"testing"
 
 	"github.com/stretchr/testify/require"
@@ -13,7 +12,7 @@ import (
 func Test_snippetList(t *testing.T) {
 	t.Parallel()
 	repo := copyTestRepo(t)
-	cmd := exec.Command(labBinaryPath, "snippet", "list", "lab-testing")
+	cmd := exec.Command(labBinaryPath, "snippet", "list", "-n", "1", "lab-testing")
 	cmd.Dir = repo
 
 	b, err := cmd.CombinedOutput()
@@ -21,8 +20,5 @@ func Test_snippetList(t *testing.T) {
 		t.Log(string(b))
 		t.Fatal(err)
 	}
-
-	snips := strings.Split(string(b), "\n")
-	t.Log(snips)
-	require.Regexp(t, `#\d+ snippet title`, snips[0])
+	require.Regexp(t, `#\d+ snippet title`, string(b))
 }
