@@ -6,9 +6,8 @@ import (
 
 var todoCmd = &cobra.Command{
 	Use:              "todo",
-	Short:            `Check out the todo list for MR or issues`,
-	Long:             ``,
-	PersistentPreRun: LabPersistentPreRun,
+	Short:            "Check out the todo list for MR or issues",
+	PersistentPreRun: labPersistentPreRun,
 	Run: func(cmd *cobra.Command, args []string) {
 		if list, _ := cmd.Flags().GetBool("list"); list {
 			todoListCmd.Run(cmd, args)
